@@ -75,7 +75,8 @@ class SaleLine:
         if (self.type != 'line'
                 or not self.product
                 or self.quantity <= 0
-                or not self.product.purchasable):
+                or not self.product.purchasable
+                or any(m.state != 'cancel' for m in self.moves)):
             return False
         return self.product.supply_on_sale
 
